"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePersistState = void 0;
var react_1 = require("react");
var PersistStateProvider_1 = require("./PersistStateProvider");
var utils_1 = require("./utils");
function usePersistState(store) {
    var client = (0, PersistStateProvider_1.usePersistStateProvider)().client;
    if (!client.fulfilledFlagMap.has(store.key)) {
        throw store.get().then(function (value) {
            client.fulfilledFlagMap.set(store.key, true);
            client.cacheMap.set(store.key, value);
        });
    }
    var _a = (0, react_1.useState)(client.cacheMap.get(store.key)), value = _a[0], setValue = _a[1];
    var setAndDispatchValue = (0, react_1.useCallback)(function (valueOrSetter) {
        setValue(function (currentValue) {
            var newValue = (0, utils_1.isFunction)(valueOrSetter)
                ? valueOrSetter(currentValue)
                : valueOrSetter;
            store.set(newValue);
            client.cacheMap.set(store.key, newValue);
            return newValue;
        });
    }, [setValue, store, client]);
    (0, react_1.useEffect)(function () {
        store.__subscribe(setValue);
        return function () {
            store.__unsubscribe(setValue);
        };
    }, [store, setValue]);
    return [value, setAndDispatchValue];
}
exports.usePersistState = usePersistState;
